@@ -1,8 +1,9 @@
 package WWW::Wolfram::DataDrop;
 
 use strict;
+use warnings;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require Exporter;
 our @ISA = 'Exporter';
@@ -64,7 +65,8 @@ WWW::Wolfram::DataDrop - Access the Wolfram DataDrop API
 
 =head1 DESCRIPTION
 
-WWW::Wolfram::DataDrop allow you to write to the Wolfram DataDrop API.
+WWW::Wolfram::DataDrop allows you to write to the Wolfram DataDrop API.
+It's not yet possible to create, remove or update DataDrops.
 
 =head1 AUTHOR
 
